Table

Struct Table 

pub struct Table { /* private fields */ }
A Wasm table entity.

Implementations

Source

impl Table

pub fn new( ty: TableType, init: TypedRawRef, limiter: &mut ResourceLimiterRef<'_>, ) -> Result<Self, TableError>

Creates a new table entity with the given resizable limits.

Errors

If init does not match the TableType element type.

pub fn ty(&self) -> TableType

Returns the resizable limits of the table.

pub fn dynamic_ty(&self) -> TableType

Returns the dynamic TableType of the Table.

Note

This respects the current size of the Table as its minimum size and is useful for import subtyping checks.

pub fn size(&self) -> u64

Returns the current size of the Table.

pub fn grow( &mut self, delta: u64, init: TypedRawRef, fuel: Option<&mut Fuel>, limiter: &mut ResourceLimiterRef<'_>, ) -> Result<u64, TableError>

Grows the table by the given amount of elements.

Returns the old size of the table upon success.

Note

This is an internal API that exists for efficiency purposes.

The newly added elements are initialized to the init RawRef.

Errors

If the table is grown beyond its maximum limits.

pub fn grow_raw( &mut self, delta: u64, init: RawRef, fuel: Option<&mut Fuel>, limiter: &mut ResourceLimiterRef<'_>, ) -> Result<u64, TableError>

Grows the table by the given amount of elements.

Returns the old size of the Table upon success.

Note

This is an internal API that exists for efficiency purposes.

The newly added elements are initialized to the init RawRef.

Errors

If the table is grown beyond its maximum limits.

pub fn get(&self, index: u64) -> Option<TypedRawRef>

Returns the raw Table element reference at index.

Returns None if index is out of bounds.

Note

This is a more efficient version of Table::get for internal use only.

pub fn set(&mut self, index: u64, value: TypedRawRef) -> Result<(), TableError>

Sets the RawRef of the table at index.

Errors

If index is out of bounds.

pub fn set_raw(&mut self, index: u64, value: RawRef) -> Result<(), TableError>

Sets the RawRef of the Table at index.

Errors

If index is out of bounds.

pub fn init( &mut self, element: ElementSegmentRef<'_>, dst_index: u64, src_index: u32, len: u32, fuel: Option<&mut Fuel>, ) -> Result<(), TableError>

Initialize len elements from src_element[src_index..] into self[dst_index..].

Errors

Returns an error if the range is out of bounds of either the source or destination tables.

Panics

If the ElementSegment element type does not match the Table element type. Note: This is a panic instead of an error since it is asserted at Wasm validation time.

pub fn copy( dst_table: &mut Self, dst_index: u64, src_table: &Self, src_index: u64, len: u64, fuel: Option<&mut Fuel>, ) -> Result<(), TableError>

Copy len elements from src_table[src_index..] into dst_table[dst_index..].

Errors

Returns an error if the range is out of bounds of either the source or destination tables.

pub fn copy_within( &mut self, dst_index: u64, src_index: u64, len: u64, fuel: Option<&mut Fuel>, ) -> Result<(), TableError>

Copy len elements from self[src_index..] into self[dst_index..].

Errors

Returns an error if the range is out of bounds of the table.

pub fn fill( &mut self, dst: u64, val: TypedRawRef, len: u64, fuel: Option<&mut Fuel>, ) -> Result<(), TableError>

Fill table[dst..(dst + len)] with the given value.

Note

This is an API for internal use only and exists for efficiency reasons.

Errors
  • If the region to be filled is out of bounds for the table.
Panics

If ctx does not own dst_table or src_table.

pub fn fill_raw( &mut self, dst: u64, val: RawRef, len: u64, fuel: Option<&mut Fuel>, ) -> Result<(), TableError>

Fill table[dst..(dst + len)] with the given value.

Note

This is an API for internal use only and exists for efficiency reasons.

Errors

If the region to be filled is out of bounds for the Table.

Panics

If ctx does not own dst_table or src_table.